"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildLambda = exports.getLambdaRole = void 0;
const aws = require("@pulumi/aws");
const pulumi = require("@pulumi/pulumi");
const utils_js_1 = require("../utils.js");
const nameRegister = utils_js_1.NameRegister.getInstance();
let registerName = (name) => {
    return nameRegister.registerName(name);
};
function getLambdaRole() {
    const iamForLambda = new aws.iam.Role(registerName('IamForLambda'), {
        assumeRolePolicy: `{
          "Version": "2012-10-17",
          "Statement": [
            {
              "Action": "sts:AssumeRole",
              "Principal": {
                "Service": [
                  "lambda.amazonaws.com"
                ]
              },
              "Effect": "Allow",
              "Sid": ""
            }
          ]
        }
        `,
    });
    const RPA = new aws.iam.RolePolicyAttachment(registerName('ServerRPABasicExecutionRole'), {
        role: iamForLambda.name,
        policyArn: aws.iam.ManagedPolicy.AWSLambdaBasicExecutionRole,
    });
    return iamForLambda;
}
exports.getLambdaRole = getLambdaRole;
function buildLambda(name, iamForLambda, codePath, environment = {}, memorySize = 128, invokeMode = 'BUFFERED') {
    const lambdaHandler = new aws.lambda.Function(registerName(name), {
        code: new pulumi.asset.FileArchive(codePath),
        role: iamForLambda.arn,
        handler: 'index.handler',
        runtime: 'nodejs18.x',
        timeout: 900,
        memorySize: memorySize,
        environment: {
            variables: Object.assign({}, environment),
        },
    });
    const lambdaURL = new aws.lambda.FunctionUrl(`${name}URL`, {
        functionName: lambdaHandler.arn,
        authorizationType: 'AWS_IAM',
        invokeMode: invokeMode,
    });
    return lambdaURL;
}
exports.buildLambda = buildLambda;
//# sourceMappingURL=resources.js.map